SocketClient class

Constructors

SocketClient({ToEncodable? toEncodable})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toEncodable ToEncodable?
final

Methods

close() → void
connect() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateFullState(Map<String, dynamic> state) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited